searchData={"items":[{"type":"module","title":"LibWechat","doc":"# LibWechat\n\nThis SDK provides an Elixir interface to interact with Wechat's APIs.\n\nHead to the [API reference](https://hexdocs.pm/lib_wechat/LibWechat.html) for usage details.","ref":"LibWechat.html"},{"type":"module","title":"Installation - LibWechat","doc":"Add the dependency to your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:lib_wechat, \"~> 0.2\"}\n  ]\nend\n```","ref":"LibWechat.html#module-installation"},{"type":"module","title":"Usage - LibWechat","doc":"1. Create a new instance of `LibWechat` with your appid and secret.\n\n```elixir\nwechat =\n  LibWechat.new(\n    appid: \"Your APP ID\",\n    secret: \"Your APP SECRET\"\n  )\n```\n\n2. Add LibWechat to your supervision tree.\n\n```elixir\nchildren = [\n  {LibWechat, wechat: wechat}\n]\n\nSupervisor.init(children, strategy: :one_for_one)\n```\n\n3. Call the API you want to use.\n\n```elixir\n# Get access token\nLibWechat.get_access_token(wechat)\n\n# Get miniapp session with code\nLibWechat.jscode_to_session(wechat, \"jscode\")\n\n# Get unlimited miniapp wxacode\nLibWechat.get_unlimited_wxacode(wechat, token,\n    %{\"scene\" => \"foo=bar\",\n      \"page\" => \"pages/index/index\",\n      \"width\" => 430,\n      \"auto_color\" => false,\n      \"line_color\" => %{\"r\" => 0, \"g\" => 0, \"b\" => 0},\n      \"is_hyaline\" => false\n    })\n\n#.... see more api in lib_wechat.ex\n```","ref":"LibWechat.html#module-usage"},{"type":"module","title":"License - LibWechat","doc":"This project is licensed under the MIT License - see the LICENSE file for details","ref":"LibWechat.html#module-license"},{"type":"function","title":"LibWechat.child_spec/1","doc":"","ref":"LibWechat.html#child_spec/1"},{"type":"function","title":"LibWechat.generate_scheme/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-scheme/urlscheme.generate.html","ref":"LibWechat.html#generate_scheme/3"},{"type":"function","title":"Examples - LibWechat.generate_scheme/3","doc":"{:ok, %{\n      \"errcode\" => 0,\n      \"errmsg\" => \"ok\",\n      \"openlink\" => \"weixin://dl/business/?t=Akeatr890b\"\n    }} = LibWechat.generate_scheme(wechat, token,\n      %{\n        \"jump_wxa\" => %{\n          \"path\" => \"pages/index/index\",\n          \"query\" => \"foo=bar\"\n        },\n        \"is_expire\" => false,\n        \"expire_type\" => 0,\n        \"expire_time\" => 0\n      }\n    )","ref":"LibWechat.html#generate_scheme/3-examples"},{"type":"function","title":"LibWechat.get_access_token/1","doc":"获取access_token\nhttps://developers.weixin.qq.com/doc/offiaccount/Basic_Information/Get_access_token.html","ref":"LibWechat.html#get_access_token/1"},{"type":"function","title":"Examples - LibWechat.get_access_token/1","doc":"{:ok, %{\"access_token\"=>\"xxx\"}} = LibWechat.get_access_token(wechat)","ref":"LibWechat.html#get_access_token/1-examples"},{"type":"function","title":"LibWechat.get_phone_number/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/phonenumber/phonenumber.getPhoneNumber.html","ref":"LibWechat.html#get_phone_number/3"},{"type":"function","title":"Examples - LibWechat.get_phone_number/3","doc":"{:ok,\n      %{\n          \"errcode\":0,\n          \"errmsg\":\"ok\",\n          \"phone_info\": {\n            \"phoneNumber\":\"xxxxxx\",\n            \"purePhoneNumber\": \"xxxxxx\",\n            \"countryCode\": 86,\n            \"watermark\": {\n                \"timestamp\": 1637744274,\n                \"appid\": \"xxxx\"\n            }\n          }\n        }\n      } = get_phone_number(wechat, token, code)","ref":"LibWechat.html#get_phone_number/3-examples"},{"type":"function","title":"LibWechat.get_unlimited_wxacode/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/qr-code/wxacode.getUnlimited.html","ref":"LibWechat.html#get_unlimited_wxacode/3"},{"type":"function","title":"Examples - LibWechat.get_unlimited_wxacode/3","doc":"{:ok, <<255, 216, ...>>} = LibWechat.get_unlimited_wxacode(wechat, token,\n      %{\"scene\" => \"foo=bar\",\n        \"page\" => \"pages/index/index\",\n        \"width\" => 430,\n        \"auto_color\" => false,\n        \"line_color\" => %{\"r\" => 0, \"g\" => 0, \"b\" => 0},\n        \"is_hyaline\" => false\n      }\n    )","ref":"LibWechat.html#get_unlimited_wxacode/3-examples"},{"type":"function","title":"LibWechat.get_urllink/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-link/urllink.generate.html","ref":"LibWechat.html#get_urllink/3"},{"type":"function","title":"Examples - LibWechat.get_urllink/3","doc":"{:ok, %{\n      \"errcode\" => 0,\n      \"errmsg\" => \"ok\",\n      \"url_link\" => \"https://wxaurl.cn/bz2LB4RMDVqq\"\n    }} = LibWechat.get_urllink(wechat, token,\n      %{\n        \"path\" => \"pages/index/index\",\n        \"query\" => \"foo=bar\",\n        \"is_expire\" => false,\n        \"expire_type\" => 0,\n        \"expire_time\" => 0\n      }\n    )","ref":"LibWechat.html#get_urllink/3-examples"},{"type":"function","title":"LibWechat.jscode_to_session/2","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/login/auth.code2Session.html","ref":"LibWechat.html#jscode_to_session/2"},{"type":"function","title":"LibWechat.msg_sec_check/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/OpenApiDoc/sec-center/sec-check/msgSecCheck.html","ref":"LibWechat.html#msg_sec_check/3"},{"type":"function","title":"Examples - LibWechat.msg_sec_check/3","doc":"iex> payload = %{\n      \"openid\"=> \"OPENID\",\n      \"scene\"=> 1,\n      \"version\"=> 2,\n      \"content\"=> \"hello world!\"\n    }\n    iex> LibWechat.msg_sec_check(wechat, token, payload)\n    {\n       \"errcode\"=> 0,\n       \"errmsg\"=> \"ok\",\n       \"result\"=> %{\n           \"suggest\"=> \"risky\",\n           \"label\"=> 20001\n       },\n       \"detail\"=> [\n           %{\n               \"strategy\"=> \"content_model\",\n               \"errcode\"=> 0,\n               \"suggest\"=> \"risky\",\n               \"label\"=> 20006,\n               \"prob\"=> 90\n           },\n           %{\n               \"strategy\": \"keyword\",\n               \"errcode\": 0,\n               \"suggest\": \"pass\",\n               \"label\": 20006,\n               \"level\": 20,\n               \"keyword\": \"命中的关键词1\"\n           },\n           {\n               \"strategy\": \"keyword\",\n               \"errcode\": 0,\n               \"suggest\": \"risky\",\n               \"label\": 20006,\n               \"level\": 90,\n               \"keyword\": \"命中的关键词2\"\n           }\n       ],\n       \"trace_id\": \"60ae120f-371d5872-7941a05b\"\n    }","ref":"LibWechat.html#msg_sec_check/3-examples"},{"type":"function","title":"LibWechat.new/1","doc":"create an instance of LibWechat","ref":"LibWechat.html#new/1"},{"type":"function","title":"options - LibWechat.new/1","doc":"* `:name` (`t:atom/0`) - name of this process The default value is `:wechat`.\n\n* `:client` (`t:term/0`) - http client instance which implements LibWechat.Http behavior The default value is `%LibWechat.Http.Default{name: LibWechat.Http.Default}`.\n\n* `:appid` (`t:String.t/0`) - Required. 第三方用户唯一凭证\n\n* `:secret` (`t:String.t/0`) - Required. 第三方用户唯一凭证密钥，即appsecret","ref":"LibWechat.html#new/1-options"},{"type":"function","title":"LibWechat.start_link/1","doc":"","ref":"LibWechat.html#start_link/1"},{"type":"function","title":"LibWechat.subscribe_send/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/subscribe-message/subscribeMessage.send.html","ref":"LibWechat.html#subscribe_send/3"},{"type":"function","title":"Examples - LibWechat.subscribe_send/3","doc":"{:ok, %{\n      \"errcode\" => 0,\n      \"errmsg\" => \"ok\",\n      \"msgid\" => 294402298110051942\n      }} = LibWechat.subscribe_send(wechat, token,\n      %{\n        \"touser\" => \"OPENID\",\n        \"template_id\" => \"TEMPLATE_ID\",\n        \"page\" => \"index\",\n        \"miniprogram_state\" => \"developer\",\n        \"lang\" => \"zh_CN\",\n        \"data\" => %{\n          \"number01\" => %{\"value\" => \"339208499\"},\n          \"date01\" => %{\"value\" => \"2015年01月05日\"},\n          \"site01\" => %{\"value\" => \"TIT创意园\"},\n          \"site02\" => %{\"value\" => \"广州市新港中路397号\"}\n        }\n      }\n    )","ref":"LibWechat.html#subscribe_send/3-examples"},{"type":"function","title":"LibWechat.uniform_send/3","doc":"https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/uniform-message/uniformMessage.send.html","ref":"LibWechat.html#uniform_send/3"},{"type":"function","title":"Examples - LibWechat.uniform_send/3","doc":"{:ok, %{\"errcode\" => 0, \"errmsg\" => \"ok\"}} = LibWechat.uniform_send(wechat, token,\n      %{\n        \"touser\" => \"OPENID\",\n        \"weapp_template_msg\" => %{\n          \"template_id\" => \"TEMPLATE_ID\",\n          \"page\" => \"index\",\n          \"form_id\" => \"FORMID\",\n          \"data\" => %{\n            \"keyword1\" => %{\"value\" => \"339208499\"},\n            \"keyword2\" => %{\"value\" => \"2015年01月05日\"},\n            \"keyword3\" => %{\"value\" => \"粤海喜来登酒店\"},\n            \"keyword4\" => %{\"value\" => \"广州市天河区天河路208号\"}\n          },\n          \"emphasis_keyword\" => \"keyword1.DATA\"\n        },\n        \"mp_template_msg\" => %{\n          \"appid\" => \"APPID \",\n          \"template_id\" => \"TEMPLATE_ID\",\n          \"url\" => \"http://weixin.qq.com/download\",\n          \"miniprogram\" => %{\n            \"appid\" => \"xiaochengxuappid12345\",\n            \"pagepath\" => \"index?foo=bar\"\n          },\n          \"data\" => %{\n            \"first\" => %{\"value\" => \"恭喜你购买成功！\", \"color\" => \"#173177\"},\n            \"keyword1\" => %{\"value\" => \"巧克力\", \"color\" => \"#173177\"},\n            \"keyword2\" => %{\"value\" => \"39.8元\", \"color\" => \"#173177\"},\n            \"keyword3\" => %{\"value\" => \"2014年9月22日\", \"color\" => \"#173177\"},\n            \"remark\" => %{\"value\" => \"欢迎再次购买！\", \"color\" => \"#173177\"}\n          }\n        }\n      })","ref":"LibWechat.html#uniform_send/3-examples"},{"type":"type","title":"LibWechat.err_t/0","doc":"","ref":"LibWechat.html#t:err_t/0"},{"type":"type","title":"LibWechat.ok_t/1","doc":"","ref":"LibWechat.html#t:ok_t/1"},{"type":"type","title":"LibWechat.options_t/0","doc":"","ref":"LibWechat.html#t:options_t/0"},{"type":"type","title":"LibWechat.t/0","doc":"","ref":"LibWechat.html#t:t/0"},{"type":"type","title":"LibWechat.token_t/0","doc":"","ref":"LibWechat.html#t:token_t/0"},{"type":"module","title":"LibWechat.Debug","doc":"debug tools","ref":"LibWechat.Debug.html"},{"type":"function","title":"LibWechat.Debug.debug/1","doc":"","ref":"LibWechat.Debug.html#debug/1"},{"type":"function","title":"LibWechat.Debug.stacktrace/1","doc":"","ref":"LibWechat.Debug.html#stacktrace/1"},{"type":"behaviour","title":"LibWechat.Http","doc":"behavior os http transport","ref":"LibWechat.Http.html"},{"type":"function","title":"LibWechat.Http.do_request/2","doc":"","ref":"LibWechat.Http.html#do_request/2"},{"type":"callback","title":"LibWechat.Http.do_request/2","doc":"","ref":"LibWechat.Http.html#c:do_request/2"},{"type":"callback","title":"LibWechat.Http.new/1","doc":"","ref":"LibWechat.Http.html#c:new/1"},{"type":"function","title":"LibWechat.Http.start_link/1","doc":"","ref":"LibWechat.Http.html#start_link/1"},{"type":"callback","title":"LibWechat.Http.start_link/1","doc":"","ref":"LibWechat.Http.html#c:start_link/1"},{"type":"type","title":"LibWechat.Http.t/0","doc":"","ref":"LibWechat.Http.html#t:t/0"},{"type":"module","title":"LibWechat.Http.Default","doc":"Implement LibWechat.Http behavior with Finch","ref":"LibWechat.Http.Default.html"},{"type":"function","title":"LibWechat.Http.Default.child_spec/1","doc":"","ref":"LibWechat.Http.Default.html#child_spec/1"},{"type":"type","title":"LibWechat.Http.Default.t/0","doc":"","ref":"LibWechat.Http.Default.html#t:t/0"},{"type":"module","title":"LibWechat.Http.Request","doc":"http request","ref":"LibWechat.Http.Request.html"},{"type":"function","title":"LibWechat.Http.Request.new/1","doc":"create new http request instance","ref":"LibWechat.Http.Request.html#new/1"},{"type":"function","title":"Params - LibWechat.Http.Request.new/1","doc":"* `:scheme` (`t:String.t/0`) - http scheme The default value is `\"https\"`.\n\n* `:host` (`t:String.t/0`) - http host The default value is `\"api.weixin.qq.com\"`.\n\n* `:port` (`t:integer/0`) - http port The default value is `443`.\n\n* `:method` (`t:term/0`) - http method The default value is `:get`.\n\n* `:path` (`t:String.t/0`) - http path The default value is `\"/\"`.\n\n* `:headers` (list of `t:term/0`) - http headers The default value is `[]`.\n\n* `:body` (`t:term/0`) - http body The default value is `nil`.\n\n* `:params` (map of `t:String.t/0` keys and `t:String.t/0` values) - http query params The default value is `%{}`.\n\n* `:opts` (`t:keyword/0`) - http opts The default value is `[]`.","ref":"LibWechat.Http.Request.html#new/1-params"},{"type":"function","title":"LibWechat.Http.Request.url/1","doc":"","ref":"LibWechat.Http.Request.html#url/1"},{"type":"type","title":"LibWechat.Http.Request.http_request_schema_t/0","doc":"","ref":"LibWechat.Http.Request.html#t:http_request_schema_t/0"},{"type":"type","title":"LibWechat.Http.Request.t/0","doc":"","ref":"LibWechat.Http.Request.html#t:t/0"},{"type":"module","title":"LibWechat.Http.Response","doc":"http response","ref":"LibWechat.Http.Response.html"},{"type":"function","title":"LibWechat.Http.Response.body/1","doc":"","ref":"LibWechat.Http.Response.html#body/1"},{"type":"function","title":"LibWechat.Http.Response.json/1","doc":"","ref":"LibWechat.Http.Response.html#json/1"},{"type":"function","title":"LibWechat.Http.Response.new/1","doc":"","ref":"LibWechat.Http.Response.html#new/1"},{"type":"type","title":"LibWechat.Http.Response.http_response_schema_t/0","doc":"","ref":"LibWechat.Http.Response.html#t:http_response_schema_t/0"},{"type":"type","title":"LibWechat.Http.Response.t/0","doc":"","ref":"LibWechat.Http.Response.html#t:t/0"},{"type":"module","title":"LibWechat.Typespecs","doc":"typespecs","ref":"LibWechat.Typespecs.html"},{"type":"type","title":"LibWechat.Typespecs.body/0","doc":"","ref":"LibWechat.Typespecs.html#t:body/0"},{"type":"type","title":"LibWechat.Typespecs.headers/0","doc":"","ref":"LibWechat.Typespecs.html#t:headers/0"},{"type":"type","title":"LibWechat.Typespecs.http_status/0","doc":"","ref":"LibWechat.Typespecs.html#t:http_status/0"},{"type":"type","title":"LibWechat.Typespecs.method/0","doc":"","ref":"LibWechat.Typespecs.html#t:method/0"},{"type":"type","title":"LibWechat.Typespecs.name/0","doc":"","ref":"LibWechat.Typespecs.html#t:name/0"},{"type":"type","title":"LibWechat.Typespecs.on_start/0","doc":"","ref":"LibWechat.Typespecs.html#t:on_start/0"},{"type":"type","title":"LibWechat.Typespecs.opts/0","doc":"","ref":"LibWechat.Typespecs.html#t:opts/0"},{"type":"type","title":"LibWechat.Typespecs.params/0","doc":"","ref":"LibWechat.Typespecs.html#t:params/0"},{"type":"type","title":"LibWechat.Typespecs.string_dict/0","doc":"","ref":"LibWechat.Typespecs.html#t:string_dict/0"},{"type":"exception","title":"LibWechat.Error","doc":"errors","ref":"LibWechat.Error.html"},{"type":"function","title":"LibWechat.Error.new/2","doc":"","ref":"LibWechat.Error.html#new/2"},{"type":"type","title":"LibWechat.Error.t/0","doc":"","ref":"LibWechat.Error.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}